$fn = 30;

module roundedRect(size, radius,height)
{
	x = size[0]-radius;
	y = size[1]-radius;
   linear_extrude(height)
	hull()
	{
		// place 4 circles in the corners, with the given radius
		translate([(-x/2)+(radius/2), (-y/2)+(radius/2), 0])
		circle(r=radius);
		
		translate([(x/2)-(radius/2), (-y/2)+(radius/2), 0])
		circle(r=radius);
		
		translate([(-x/2)+(radius/2), (y/2)-(radius/2), 0])
		circle(r=radius);
		
		translate([(x/2)-(radius/2), (y/2)-(radius/2), 0])
		circle(r=radius);
	}
}

module notroundedRect(size, radius,height)
{
	x = size[0]-radius;
	y = size[1]-radius;
   linear_extrude(height)
	hull()
	{
		// place 4 circles in the corners, with the given radius
		translate([(-x/2)+(radius/2)-5, (-y/2)+(radius/2), 0])
		circle(r=radius);
		
		translate([(x/2)-(radius/2)-5, (-y/2)+(radius/2), 0])
		circle(r=radius);
		
		translate([(-x/2)+(radius/2), (y/2)-(radius/2), 0])
		circle(r=radius);
		
		translate([(x/2)-(radius/2), (y/2)-(radius/2), 0])
		circle(r=radius);
	}
}

module standoffhole() {
	  cylinder(h=28.5,r=2.0/2, center=true);
}

module standoff() {
	  cylinder(h=28.5,r=5/2, center=true);
}

module box() {
  union()
  { 
    roundedRect([46.75-3.0,93.25-2,13],4.0,2);  //outside box face 
    difference() {
 	  roundedRect([46.75-3,93.25-2,13],4.0,10);  //outside box
  	  roundedRect([46.75-6.64,93.25+1-6.64,13],2.5,10.1);  //inside box  // was 2.64 thick
    }
  }
}


module lcdbox() {
difference() {
  union() {  
//    box();
    translate([-31/2,-75/2 -0.2 ,2+5.5/2]) standoff();
    translate([-31/2,+75/2 -0.2 + 0.8,2+5.5/2]) standoff();
    translate([+31/2 +0.9,+75/2 -0.2 + 0.8,2+5.5/2]) standoff();
    translate([+31/2 +0.9,-75/2 -0.2 ,2+5.5/2]) standoff();
  }
  union() {
    cube([27.5,72.5,5],center=true);  //cutout lcd window
    translate([-31/2,-75/2 -0.2 ,2+5.5/2]) standoffhole();  
    translate([-31/2,+75/2 -0.2 + 0.8,2+5.5/2]) standoffhole();
    translate([+31/2 +0.9,+75/2 -0.2 + 0.8,2+5.5/2]) standoffhole();
    translate([+31/2 +0.9,-75/2 -0.2 ,2+5.5/2]) standoffhole();  
  }
}
}

module switch() {
  difference() {  
    translate([ -50.6-(25.2/2)+2 ,1.6 ,30.3/2-4.5 ]  )  rotate([-6,0,0]) 
      
      difference() {
        cube([25.2+4, 51.6-0.3, 30.3 -3.5],center=true);  // solid chunk outside dimensions
        union() {  
          translate([1.8,24,-4.5+1]) cube([18+0.8, 1, 8+2],center=true);     
          translate([1.8,-24,-8.7+2.5]) cube([18+0.8, 1, 14],center=true);              
          translate([1.9,0,0]) cube([18+0.8, 47.2, 30.3+0.1],center=true);
          translate([0,0,14.8/2 -1 ]) cube([21.8 +0.4, 47.6, 14.8+0.8 +7],center=true);
          translate([2,0,14.8/2+2.7-1  ]) cube([26, 34+0.4, 17.5],center=true);
          translate([0,0,13-3.5-3.5-1  ]) cube([12.7, 52, 3],center=true);        
        }
      } 
      translate([-48 -(25.2/2),0,-4]) cube([32, 60, 8],center=true);
  }
}

module snap() {
   difference() {
       
     union() { 
       cube([10,4,12.5]);
       rotate([-30,0,0]) translate([0,-5,6]) cube([10,3,5.7]);
     }
     union() {  
      rotate([-30,0,0]) translate([-0.1,-8,5]) cube([10.2,3,6.7]);
      translate([-0.1,-3,1]) cube([10.2,3,6.7]);           
     }
   }
}


module makeit() {

difference() {
    notroundedRect([162,58],8,4);
    union() {
    translate([30,3-4,0]) rotate([0,0,90]) cube([36.5,72.5,9],center=true);  //lcd
    translate([30,20.7+0.8,4]) rotate([0,0,90]) cube([7,72.5+10,4],center=true);  //lcd     
        
    translate([-62+2+33.7 , 0.8,-0.1]) rotate([0,0,90]) roundedRect([48.6,19.8],2,5.1);    //switch
    translate([-60+3,-5 -5 -3,0]) cylinder(r=3.7,h=5);    // rotary encoder shaft 3.7
    translate([-60 -16/2 +3 , -5 - 13/2 -5 -3,2]) cube([16,13,3]);    // rotary encoder square
    translate([-60-5 , -11-3 ,1]) cube([3,2,3]);    // rotary encoder square
        intersection() {
          translate([-58,11,0]) cylinder(r=20.5/2,h=5); // USB circle hole
          translate([-58-(20.5/2),11-(14.5/2),0]) cube([20.5 ,14.5 ,4 ]); // rect circle
        }
        translate([-58-(6/2),11-(20/2),0]) cube([5.5,21,4]); // USB flexible tabs
        translate([-58-(6/2),11-(21/2),2]) cube([5.5,22,2]); // USB flexible tabs
        translate([-58-(22/2),11-(2/2),0]) cube([22,2,4]); // USB tiny tabs
    }
}
 

translate([56,28.8,3]) rotate([6,0,180]) snap();
translate([-45,28.8,3]) rotate([6,0,180]) snap();
rotate([-6,0,0]) translate([39,-28.8+1,0]) snap();
rotate([-6,0,0]) translate([-64,-28.8+1,0]) snap(); 
}

module finalbox() {

makeit();
translate([33,0,3.5]) switch();
difference() {
  union() {
  translate([30,-3,0]) rotate([0,40,90]) lcdbox();
  difference() {    
    translate([-7.5,0.5,4]) rotate([50,0,0]) cube([2,24.3,28.5],center=true);  //sides
    translate([-7.5,8,12.5]) rotate([50,0,0]) cube([2,2.2,16],center=true);  //sides  
  }    
  translate([67.5,0.5,4]) rotate([50,0,0]) cube([2,24.3,28.5],center=true);  //sides
  translate([30,-12,13.2]) rotate([-40,0,0]) cube([72,2,26],center=true);  //sides      
//  translate([30,-4.2,21]) rotate([0,0,0]) cube([72,2,2],center=true);  //sides bar
  translate([30,20.7-2.3,3]) rotate([0,0,90]) cube([2,72.5+10,2],center=true); // small bar
  
  }
  translate([30,0,-20/2]) cube([92,50,20],center=true);  
}

}

difference() {
finalbox();
 union() {
  // translate([35,0,0]) cube([92,70,52],center=true);
  // translate([-90,0,0]) cube([92,70,52],center=true);  
 }
}